@@ -1,7 +1,7 @@
 package Dist::Inkt::Profile::TOBYINK;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.006';
+our $VERSION   = '0.007';
 
 use Moose;
 
@@ -18,7 +18,7 @@ with qw(
 	Dist::Inkt::Role::WriteMakefilePL
 	Dist::Inkt::Role::WriteMetaJSON
 	Dist::Inkt::Role::WriteMetaYML
-	Dist::Inkt::Role::WriteMetaTTL
+	Dist::Inkt::Role::WriteDOAP
 	Dist::Inkt::Role::WriteChanges
 	Dist::Inkt::Role::WriteCOPYRIGHT
 	Dist::Inkt::Role::WriteCREDITS
